from wegene.Controllers.WeGeneUser import *
from wegene.Controllers.Allele import *
from wegene.Controllers.Health import *
from wegene.Controllers.Athletigen import *
from wegene.Controllers.Risk import *
from wegene.Controllers.Haplogroups import *
from wegene.Controllers.Ancestry import *
from wegene.Controllers.Demographics import *
