# -*- coding: utf-8 -*-

"""
   wegene.Configuration

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""

class Configuration :
    # The base Uri for API calls
    BASE_URI = "https://api.wegene.com"

    # The OAuth 2.0 access token to be set before API calls
    # TODO: Replace the o_auth_access_token with an appropriate value
    o_auth_access_token = "TODO: Replace"
